==> spip_3.2.11.orig.tar.xz: plugins-dist/compagnon/lang/compagnon_uk.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/compagnon?lang_cible=uk
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// C
	'c_accueil_bienvenue' => 'Доброго дня, @nom@!',
	'c_accueil_configurer_site' => 'Налаштувати сайт',
	'c_accueil_configurer_site_texte' => 'Перше, що ви можете зробити, - це змінити назву вашого сайту.
Зараз він називається „@nom@”. Назву показано в правому верхньому кутку сторінки. Ви можете змінити ім’я сайту, натиснувши на нього.',
	'c_accueil_publication' => 'Опублікувати!',
	'c_accueil_publication_texte' => 'Щоб зробити нову сторінку сайту вам необхідно створити нову статтю. Також необхідно, аби у вас була хоча б одна рубрика. Якщо на сайті нема жодної рубрики, ви можете створити першу з них, натиснувши на пункт меню „Редагувати->Рубрики” у верхній панелі управління.',
	'c_accueil_texte' => 'Ви тільки но увішли в систему управління вашими сайтом - CMS SPIP.',
	'c_accueil_texte_revenir' => 'На цій сторінці відображаються останні редагування, які були виконані на сайті. В подальшому ви можете повернутися на цю сторінку, натиснувши на кнопку «Головна» в лівому верхньому кутку сторінки.',
	'c_article_redaction' => 'Статус статті - “редагується”',
	'c_article_redaction_redacteur' => 'Ця редакція статті - “в процесі”',
	'c_article_redaction_redacteur_texte' => 'Щоб відправити статтю на затвердження адміністратором(ами) сайту, змініть статус статті з “готується” на “затверджується”.',
	'c_article_redaction_texte' => 'Щоб стаття з’явилась на сайті, ви повинні змінити її статус. У лівій колонці змініть статус статті з „редагується” на „опубликовано”.',
	'c_articles_creer' => 'Як створити статтю?',
	'c_articles_creer_texte' => 'Ви не можете створити статтю на цій сторінці доти, доки ви не створили хоча б одну рубрику сайту. Щоб створити рубрику наведіть мишку на кнопку “Редагувати” і виберіть пункт меню “Рубрики”.',
	'c_job' => 'Список завдань',
	'c_job_texte' => 'На цій сторінці ви бачите список завдань, які виконує CMS SPIP. Деякі завдання виконуються періодично, інші - час від часу, наприклад відправлення розсилки дописувачам.',
	'c_rubrique_publier' => 'Створіть статтю',
	'c_rubrique_publier_texte' => 'Рубрика з’являється на сайті тільки тоді, коли вона містить мінімум одну опубліковану статтю. Якщо на вашому сайті на початку назви рубрики вказаний номер, то це її номер по порядку при виведенні на сторінках сайту. В такому випадку рубрики без номерів також показуватися не будуть. Ви можете користатися цією особливістю, щоб сховати рубрику.
Отже, створіть статтю. Кнопка знаходиться на цій сторінці під описом рубрики.',
	'c_rubriques_creer' => 'Створіть першу рубрику!',
	'c_rubriques_creer_texte' => 'Рубрики - це основа структури сайту; ви можете створювати і зберігати файли в них. Спробуйте створити першу рубрику.',
	'c_sites_creer' => 'Як створити або імпортувати сайт?',
	'c_sites_creer_texte' => 'Ви не можете створити або імпортувати сайт з цієї сторінки доти, доки не існує рубрик на вашому сайті. 
Ви можете створити рубрики в меню „Редагувати”, підменю „Рубрики”.',

	// E
	'explication_activer_compagnon' => '„Помічник” виводить спеціальні пояснення на деяких сторінках адміністративної частини сайту, щоб користувачу було легше почати роботу. Чи бажаєте ви увімкнути „Помічника”?',
	'explication_reinitialiser_compagnon' => 'Підказки, які користувач вже бачив, не будуть показуватися надалі. Показати підказки знову?',

	// L
	'label_activer_compagnon' => 'Включити „Помічника”?',
	'label_reinitialiser_compagnon' => 'Показати знову підказки „Помічника”?',

	// O
	'ok' => 'OK',
	'ok_bien' => 'Добре!',
	'ok_jai_compris' => 'Готово!',
	'ok_merci' => 'Дякую',
	'ok_parfait' => 'Чудово!',

	// R
	'reinitialisation' => 'Показати знову підказки',
	'reinitialisation_ok' => 'Виконується...',
	'reinitialiser' => 'Скинути',
	'reinitialiser_moi' => 'Так, лише для мене',
	'reinitialiser_tous' => 'Так, для всіх авторів',

	// T
	'titre_compagnon' => '„Помічник”',
	'titre_page_configurer_compagnon' => 'Налаштування „Помічника”'
);

==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/compagnon/lang/compagnon_uk.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/compagnon?lang_cible=uk
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_tout_compris' => 'Сховати всі повідомлення плагіну',
	'bouton_tout_compris_explication' => 'Якщо ви добре знайомі з системою SPIP ви можете відмовитися від перегляду всіх інформаційних повідомлень.',

	// C
	'c_accueil_bienvenue' => 'Доброго дня, @nom@!',
	'c_accueil_configurer_site' => 'Налаштувати сайт',
	'c_accueil_configurer_site_texte' => 'Перше, що ви можете зробити, - це змінити назву вашого сайту.
Зараз він називається „@nom@”. Назву показано в правому верхньому кутку сторінки. Ви можете змінити ім’я сайту, натиснувши на нього.',
	'c_accueil_publication' => 'Опублікувати!',
	'c_accueil_publication_texte' => 'Щоб зробити нову сторінку сайту вам необхідно створити нову статтю. Також необхідно, аби у вас була хоча б одна рубрика. Якщо на сайті нема жодної рубрики, ви можете створити першу з них, натиснувши на пункт меню „Редагувати->Рубрики” у верхній панелі управління.',
	'c_accueil_texte' => 'Ви тільки но увішли в систему управління вашими сайтом - CMS SPIP.',
	'c_accueil_texte_revenir' => 'На цій сторінці відображаються останні редагування, які були виконані на сайті. В подальшому ви можете повернутися на цю сторінку, натиснувши на кнопку «Головна» в лівому верхньому кутку сторінки.',
	'c_article_redaction' => 'Статус статті - “редагується”',
	'c_article_redaction_redacteur' => 'Ця редакція статті - “в процесі”',
	'c_article_redaction_redacteur_texte' => 'Щоб відправити статтю на затвердження адміністратором(ами) сайту, змініть статус статті з “готується” на “затверджується”.',
	'c_article_redaction_texte' => 'Щоб стаття з’явилась на сайті, ви повинні змінити її статус. У лівій колонці змініть статус статті з „редагується” на „опубликовано”.',
	'c_articles_creer' => 'Як створити статтю?',
	'c_articles_creer_texte' => 'Ви не можете створити статтю на цій сторінці доти, доки ви не створили хоча б одну рубрику сайту. Щоб створити рубрику наведіть мишку на кнопку “Редагувати” і виберіть пункт меню “Рубрики”.',
	'c_job' => 'Список завдань',
	'c_job_texte' => 'На цій сторінці ви бачите список завдань, які виконує CMS SPIP. Деякі завдання виконуються періодично, інші - час від часу, наприклад відправлення розсилки дописувачам.',
	'c_rubrique_publier' => 'Створіть статтю',
	'c_rubrique_publier_texte' => 'Рубрика з’являється на сайті тільки тоді, коли вона містить мінімум одну опубліковану статтю. Якщо на вашому сайті на початку назви рубрики вказаний номер, то це її номер по порядку при виведенні на сторінках сайту. В такому випадку рубрики без номерів також показуватися не будуть. Ви можете користатися цією особливістю, щоб сховати рубрику.
Отже, створіть статтю. Кнопка знаходиться на цій сторінці під описом рубрики.',
	'c_rubriques_creer' => 'Створіть першу рубрику!',
	'c_rubriques_creer_texte' => 'Рубрики - це основа структури сайту; ви можете створювати і зберігати файли в них. Спробуйте створити першу рубрику.',
	'c_sites_creer' => 'Як створити або імпортувати сайт?',
	'c_sites_creer_texte' => 'Ви не можете створити або імпортувати сайт з цієї сторінки доти, доки не існує рубрик на вашому сайті. 
Ви можете створити рубрики в меню „Редагувати”, підменю „Рубрики”.',

	// E
	'explication_activer_compagnon' => '„Помічник” виводить спеціальні пояснення на деяких сторінках адміністративної частини сайту, щоб користувачу було легше почати роботу. Чи бажаєте ви увімкнути „Помічника”?',
	'explication_reinitialiser_compagnon' => 'Підказки, які користувач вже бачив, не будуть показуватися надалі. Показати підказки знову?',

	// L
	'label_activer_compagnon' => 'Включити „Помічника”?',
	'label_reinitialiser_compagnon' => 'Показати знову підказки „Помічника”?',

	// O
	'ok' => 'OK',
	'ok_bien' => 'Добре!',
	'ok_jai_compris' => 'Готово!',
	'ok_merci' => 'Дякую',
	'ok_parfait' => 'Чудово!',

	// R
	'reinitialisation' => 'Показати знову підказки',
	'reinitialisation_ok' => 'Виконується...',
	'reinitialiser' => 'Скинути',
	'reinitialiser_moi' => 'Так, лише для мене',
	'reinitialiser_tous' => 'Так, для всіх авторів',

	// T
	'titre_compagnon' => '„Помічник”',
	'titre_page_configurer_compagnon' => 'Налаштування „Помічника”'
);
